@@ -1,8 +1,7 @@
 package CGI::Application::Plugin::Authentication::Driver::Filter::crypt;
-
+$CGI::Application::Plugin::Authentication::Driver::Filter::crypt::VERSION = '0.21';
 use strict;
 use warnings;
-our $VERSION = '0.20';
 
 sub check {
     my $class    = shift;
@@ -14,10 +13,7 @@ sub check {
 }
 
 sub filter {
-    my $class = shift;
-    my $param = lc shift; # not used
-    my $plain = shift;
-    my $salt  = shift;
+    my ($class, undef, $plain, $salt) = @_;
     if (!$salt) {
         my @alphabet = ( '.', '/', 0 .. 9, 'A' .. 'Z', 'a' .. 'z' );
         $salt = join '', @alphabet[ rand 64, rand 64 ];
@@ -33,10 +29,6 @@ __END__
 
 CGI::Application::Plugin::Authentication::Driver::Filter::crypt - crypt Filter
 
-=head1 VERSION
-
-This document describes CGI::Application::Plugin::Authentication::Driver::Filter::crypt version 0.20
-
 =head1 METHODS
 
 
