@@ -1,8 +1,7 @@
 package CGI::Application::Plugin::Authentication::Driver::Filter::md5;
-
+$CGI::Application::Plugin::Authentication::Driver::Filter::md5::VERSION = '0.21';
 use strict;
 use warnings;
-our $VERSION = '0.20';
 
 use UNIVERSAL::require;
 
@@ -25,7 +24,7 @@ sub check {
 
 sub filter {
     my $class = shift;
-    my $param = lc shift || 'hex';
+    my $param = lc (shift || 'hex');
     my $plain = shift;
 
     Digest::MD5->require || die "Digest::MD5 is required to check MD5 passwords";
@@ -47,10 +46,6 @@ __END__
 
 CGI::Application::Plugin::Authentication::Driver::Filter::md5 - MD5 filter
 
-=head1 VERSION
-
-This document describes CGI::Application::Plugin::Authentication::Driver::Filter::md5 version 0.20
-
 =head1 METHODS
 
 =head2 filter ( (hex base64 binary), $string )
